Module breadx::auto [−][src]
This module contains data formats and functions that were automatically generated from the XmlXcb
description of the X11 protocol. If you want direct access to the X11 protocol's internals, it's
recommended to use these functions, as well as the Display object's send_request,
resolve_request and wait_for_event functions.
Modules
| bigreq | |
| damage | |
| dpms | |
| dri2 | |
| dri3 | |
| ge | |
| glx | |
| present | |
| randr | |
| record | |
| render | The X Rendering composite system. |
| res | |
| screensaver | |
| shape | |
| shm | |
| sync | |
| xc_misc | Miscellaneous additions to the X11 protocol. |
| xevie | |
| xf86dri | |
| xf86vidmode | |
| xfixes | |
| xinerama | |
| xinput | |
| xkb | |
| xprint | |
| xproto | The core X11 protocol. |
| xselinux | |
| xtest | |
| xv | |
| xvmc |
Traits
| AsByteSequence | Internal use helper trait. This represents an item that can be converted to and from a series of bytes. |
| Error | An error. |
| Event | An event. |