Struct breadx::auto::glx::BufferSwapCompleteEvent [−][src]
pub struct BufferSwapCompleteEvent {
pub event_type: u8,
pub sequence: u16,
pub event_type_: u16,
pub drawable: Drawable,
pub ust_hi: u32,
pub ust_lo: u32,
pub msc_hi: u32,
pub msc_lo: u32,
pub sbc: u32,
}Fields
event_type: u8sequence: u16event_type_: u16drawable: Drawableust_hi: u32ust_lo: u32msc_hi: u32msc_lo: u32sbc: u32Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more