Struct breadx::auto::glx::SetClientInfo2ArbRequest [−][src]
pub struct SetClientInfo2ArbRequest<'t, 'u, 'v> {
pub req_type: u8,
pub length: u16,
pub major_version: u32,
pub minor_version: u32,
pub num_versions: u32,
pub gl_versions: Cow<'t, [u32]>,
pub gl_extension_string: Cow<'u, str>,
pub glx_extension_string: Cow<'v, str>,
}Fields
req_type: u8length: u16major_version: u32minor_version: u32num_versions: u32gl_versions: Cow<'t, [u32]>gl_extension_string: Cow<'u, str>glx_extension_string: Cow<'v, str>Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
impl<'t, 'u, 'v> PartialEq<SetClientInfo2ArbRequest<'t, 'u, 'v>> for SetClientInfo2ArbRequest<'t, 'u, 'v>[src]
impl<'t, 'u, 'v> PartialEq<SetClientInfo2ArbRequest<'t, 'u, 'v>> for SetClientInfo2ArbRequest<'t, 'u, 'v>[src]This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<'t, 'u, 'v> PartialOrd<SetClientInfo2ArbRequest<'t, 'u, 'v>> for SetClientInfo2ArbRequest<'t, 'u, 'v>[src]
impl<'t, 'u, 'v> PartialOrd<SetClientInfo2ArbRequest<'t, 'u, 'v>> for SetClientInfo2ArbRequest<'t, 'u, 'v>[src]This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more