Struct breadx::auto::randr::GetScreenInfoReply [−][src]
pub struct GetScreenInfoReply<'b, 'd, 'c> {Show fields
pub reply_type: u8,
pub rotations: Rotation,
pub sequence: u16,
pub length: u32,
pub root: Window,
pub timestamp: Timestamp,
pub config_timestamp: Timestamp,
pub n_sizes: u16,
pub size_id: u16,
pub rotation: Rotation,
pub rate: u16,
pub n_info: u16,
pub sizes: Cow<'b, [ScreenSize]>,
pub rates: Cow<'d, [RefreshRates<'c>]>,
}Fields
reply_type: u8rotations: Rotationsequence: u16length: u32root: Windowtimestamp: Timestampconfig_timestamp: Timestampn_sizes: u16size_id: u16rotation: Rotationrate: u16n_info: u16sizes: Cow<'b, [ScreenSize]>rates: Cow<'d, [RefreshRates<'c>]>Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more