Struct breadx::auto::sync::ChangeAlarmRequest [−][src]
pub struct ChangeAlarmRequest {
pub req_type: u8,
pub length: u16,
pub id: Alarm,
pub value_mask: Ca,
pub counter: Counter,
pub value_type: Valuetype,
pub value: i64,
pub test_type: Testtype,
pub delta: i64,
pub events: u32,
}Fields
req_type: u8length: u16id: Alarmvalue_mask: Cacounter: Countervalue_type: Valuetypevalue: i64test_type: Testtypedelta: i64events: u32Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more