Trait breadx::auto::AsByteSequence [−][src]
pub trait AsByteSequence: Sized { fn size(&self) -> usize; fn as_bytes(&self, bytes: &mut [u8]) -> usize; fn from_bytes(bytes: &[u8]) -> Option<(Self, usize)>; fn file_descriptors(&mut self) -> Option<&mut Vec<Fd>> { ... } }
Internal use helper trait. This represents an item that can be converted to and from a series of bytes.
Required methods
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items.
Provided methods
fn file_descriptors(&mut self) -> Option<&mut Vec<Fd>>[src]
fn file_descriptors(&mut self) -> Option<&mut Vec<Fd>>[src]If this item has any file descriptors stored within, this function returns them.
Implementations on Foreign Types
Implementors
impl<'ad, 'vc, 'wc, 'xc, 'yc, 'zc> AsByteSequence for XiQueryDeviceReply<'ad, 'vc, 'wc, 'xc, 'yc, 'zc>[src]
impl<'ad, 'vc, 'wc, 'xc, 'yc, 'zc> AsByteSequence for XiQueryDeviceReply<'ad, 'vc, 'wc, 'xc, 'yc, 'zc>[src]impl<'bd, 'zc, 'ad, 'dd, 'cd, 'ed, 'fd, 'gd, 'hd, 'id, 'jd, 'kd, 'ld, 'md, 'nd, 'od, 'pd, 'qd, 'rd, 'sd, 'td, 'ud, 'vd, 'wd, 'xd, 'yd> AsByteSequence for GetKbdByNameReply<'bd, 'zc, 'ad, 'dd, 'cd, 'ed, 'fd, 'gd, 'hd, 'id, 'jd, 'kd, 'ld, 'md, 'nd, 'od, 'pd, 'qd, 'rd, 'sd, 'td, 'ud, 'vd, 'wd, 'xd, 'yd>[src]
impl<'bd, 'zc, 'ad, 'dd, 'cd, 'ed, 'fd, 'gd, 'hd, 'id, 'jd, 'kd, 'ld, 'md, 'nd, 'od, 'pd, 'qd, 'rd, 'sd, 'td, 'ud, 'vd, 'wd, 'xd, 'yd> AsByteSequence for GetKbdByNameReply<'bd, 'zc, 'ad, 'dd, 'cd, 'ed, 'fd, 'gd, 'hd, 'id, 'jd, 'kd, 'ld, 'md, 'nd, 'od, 'pd, 'qd, 'rd, 'sd, 'td, 'ud, 'vd, 'wd, 'xd, 'yd>[src]impl<'ec, 'fc, 'gc, 'hc, 'ic, 'jc, 'kc, 'lc, 'mc> AsByteSequence for SetNamesRequest<'ec, 'fc, 'gc, 'hc, 'ic, 'jc, 'kc, 'lc, 'mc>[src]
impl<'ec, 'fc, 'gc, 'hc, 'ic, 'jc, 'kc, 'lc, 'mc> AsByteSequence for SetNamesRequest<'ec, 'fc, 'gc, 'hc, 'ic, 'jc, 'kc, 'lc, 'mc>[src]impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> AsByteSequence for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>[src]
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> AsByteSequence for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>[src]impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> AsByteSequence for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> AsByteSequence for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]impl<'t, 'r, 's, 'v, 'u, 'w, 'x, 'y, 'z, 'ab, 'bb, 'cb> AsByteSequence for GetMapReply<'t, 'r, 's, 'v, 'u, 'w, 'x, 'y, 'z, 'ab, 'bb, 'cb>[src]
impl<'t, 'r, 's, 'v, 'u, 'w, 'x, 'y, 'z, 'ab, 'bb, 'cb> AsByteSequence for GetMapReply<'t, 'r, 's, 'v, 'u, 'w, 'x, 'y, 'z, 'ab, 'bb, 'cb>[src]impl<'vb, 'wb, 'xb, 'yb, 'zb, 'ac, 'bc, 'cc, 'dc> AsByteSequence for GetNamesReply<'vb, 'wb, 'xb, 'yb, 'zb, 'ac, 'bc, 'cc, 'dc>[src]
impl<'vb, 'wb, 'xb, 'yb, 'zb, 'ac, 'bc, 'cc, 'dc> AsByteSequence for GetNamesReply<'vb, 'wb, 'xb, 'yb, 'zb, 'ac, 'bc, 'cc, 'dc>[src]impl<'zd, 'ae, 'de, 'be, 'ce> AsByteSequence for breadx::auto::xkb::GetDeviceInfoReply<'zd, 'ae, 'de, 'be, 'ce>[src]
impl<'zd, 'ae, 'de, 'be, 'ce> AsByteSequence for breadx::auto::xkb::GetDeviceInfoReply<'zd, 'ae, 'de, 'be, 'ce>[src]