Struct breadx::auto::xf86vidmode::GetMonitorReply [−][src]
pub struct GetMonitorReply<'c, 'd, 'e, 'f, 'g> {
pub reply_type: u8,
pub sequence: u16,
pub length: u32,
pub vendor_length: u8,
pub hsync: Cow<'c, [Syncrange]>,
pub vsync: Cow<'d, [Syncrange]>,
pub vendor: Cow<'e, str>,
pub alignment_pad: Cow<'f, [u8]>,
pub model: Cow<'g, str>,
}Fields
reply_type: u8sequence: u16length: u32vendor_length: u8hsync: Cow<'c, [Syncrange]>vsync: Cow<'d, [Syncrange]>vendor: Cow<'e, str>alignment_pad: Cow<'f, [u8]>model: Cow<'g, str>Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
impl<'c, 'd, 'e, 'f, 'g> PartialEq<GetMonitorReply<'c, 'd, 'e, 'f, 'g>> for GetMonitorReply<'c, 'd, 'e, 'f, 'g>[src]
impl<'c, 'd, 'e, 'f, 'g> PartialEq<GetMonitorReply<'c, 'd, 'e, 'f, 'g>> for GetMonitorReply<'c, 'd, 'e, 'f, 'g>[src]This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<'c, 'd, 'e, 'f, 'g> PartialOrd<GetMonitorReply<'c, 'd, 'e, 'f, 'g>> for GetMonitorReply<'c, 'd, 'e, 'f, 'g>[src]
impl<'c, 'd, 'e, 'f, 'g> PartialOrd<GetMonitorReply<'c, 'd, 'e, 'f, 'g>> for GetMonitorReply<'c, 'd, 'e, 'f, 'g>[src]This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more