Struct breadx::auto::xinput::DeviceCtl [−][src]
pub struct DeviceCtl<'tb> {Show fields
pub control_id: DeviceControl,
pub len: u16,
pub first_valuator: u8,
pub resolution_values: Cow<'tb, [u32]>,
pub min_x: i32,
pub max_x: i32,
pub min_y: i32,
pub max_y: i32,
pub flip_x: u32,
pub flip_y: u32,
pub rotation: u32,
pub button_threshold: u32,
pub status: u8,
pub enable: u8,
pub offset_x: u32,
pub offset_y: u32,
pub width: i32,
pub height: i32,
pub screen: i32,
pub following: u32,
}Fields
control_id: DeviceControllen: u16first_valuator: u8resolution_values: Cow<'tb, [u32]>min_x: i32max_x: i32min_y: i32max_y: i32flip_x: u32flip_y: u32rotation: u32status: u8enable: u8offset_x: u32offset_y: u32width: i32height: i32screen: i32following: u32Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more