Struct breadx::auto::xinput::XiChangePropertyRequest [−][src]
pub struct XiChangePropertyRequest<'hd, 'id, 'jd> {
pub req_type: u8,
pub length: u16,
pub deviceid: DeviceId,
pub mode: PropMode,
pub format: PropertyFormat,
pub property: Atom,
pub ty: Atom,
pub num_items: u32,
pub data8: Cow<'hd, [u8]>,
pub data16: Cow<'id, [u16]>,
pub data32: Cow<'jd, [u32]>,
}Fields
req_type: u8length: u16deviceid: DeviceIdmode: PropModeformat: PropertyFormatproperty: Atomty: Atomnum_items: u32data8: Cow<'hd, [u8]>data16: Cow<'id, [u16]>data32: Cow<'jd, [u32]>Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
impl<'hd, 'id, 'jd> PartialEq<XiChangePropertyRequest<'hd, 'id, 'jd>> for XiChangePropertyRequest<'hd, 'id, 'jd>
impl<'hd, 'id, 'jd> PartialEq<XiChangePropertyRequest<'hd, 'id, 'jd>> for XiChangePropertyRequest<'hd, 'id, 'jd>This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<'hd, 'id, 'jd> PartialOrd<XiChangePropertyRequest<'hd, 'id, 'jd>> for XiChangePropertyRequest<'hd, 'id, 'jd>
impl<'hd, 'id, 'jd> PartialOrd<XiChangePropertyRequest<'hd, 'id, 'jd>> for XiChangePropertyRequest<'hd, 'id, 'jd>This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more