Struct breadx::auto::xkb::GetCompatMapReply [−][src]
pub struct GetCompatMapReply<'pb, 'qb> {
pub reply_type: u8,
pub device_id: u8,
pub sequence: u16,
pub length: u32,
pub groups_rtrn: SetOfGroup,
pub first_si_rtrn: u16,
pub n_total_si: u16,
pub si_rtrn: Cow<'pb, [SymInterpret]>,
pub group_rtrn: Cow<'qb, [ModDef]>,
}Fields
reply_type: u8device_id: u8sequence: u16length: u32groups_rtrn: SetOfGroupfirst_si_rtrn: u16n_total_si: u16si_rtrn: Cow<'pb, [SymInterpret]>group_rtrn: Cow<'qb, [ModDef]>Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more