Struct breadx::auto::xkb::GetControlsReply [−][src]
pub struct GetControlsReply {Show fields
pub reply_type: u8,
pub device_id: u8,
pub sequence: u16,
pub length: u32,
pub mouse_keys_dflt_btn: u8,
pub num_groups: u8,
pub groups_wrap: u8,
pub internal_mods_mask: ModMask,
pub ignore_lock_mods_mask: ModMask,
pub internal_mods_real_mods: ModMask,
pub ignore_lock_mods_real_mods: ModMask,
pub internal_mods_vmods: VMod,
pub ignore_lock_mods_vmods: VMod,
pub repeat_delay: u16,
pub repeat_interval: u16,
pub slow_keys_delay: u16,
pub debounce_delay: u16,
pub mouse_keys_delay: u16,
pub mouse_keys_interval: u16,
pub mouse_keys_time_to_max: u16,
pub mouse_keys_max_speed: u16,
pub mouse_keys_curve: i16,
pub access_x_option: AxOption,
pub access_x_timeout: u16,
pub access_x_timeout_options_mask: AxOption,
pub access_x_timeout_options_values: AxOption,
pub access_x_timeout_mask: BoolCtrl,
pub access_x_timeout_values: BoolCtrl,
pub enabled_controls: BoolCtrl,
pub per_key_repeat: [u8; 32],
}Fields
reply_type: u8device_id: u8sequence: u16length: u32mouse_keys_dflt_btn: u8num_groups: u8groups_wrap: u8internal_mods_mask: ModMaskignore_lock_mods_mask: ModMaskinternal_mods_real_mods: ModMaskignore_lock_mods_real_mods: ModMaskinternal_mods_vmods: VModignore_lock_mods_vmods: VModrepeat_delay: u16repeat_interval: u16slow_keys_delay: u16debounce_delay: u16mouse_keys_delay: u16mouse_keys_interval: u16mouse_keys_time_to_max: u16mouse_keys_max_speed: u16mouse_keys_curve: i16access_x_option: AxOptionaccess_x_timeout: u16access_x_timeout_options_mask: AxOptionaccess_x_timeout_options_values: AxOptionaccess_x_timeout_mask: BoolCtrlaccess_x_timeout_values: BoolCtrlenabled_controls: BoolCtrlper_key_repeat: [u8; 32]Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more