Struct breadx::auto::xkb::GetStateReply [−][src]
pub struct GetStateReply {Show fields
pub reply_type: u8,
pub device_id: u8,
pub sequence: u16,
pub length: u32,
pub mods: ModMask,
pub base_mods: ModMask,
pub latched_mods: ModMask,
pub locked_mods: ModMask,
pub group: Group,
pub locked_group: Group,
pub base_group: i16,
pub latched_group: i16,
pub compat_state: ModMask,
pub grab_mods: ModMask,
pub compat_grab_mods: ModMask,
pub lookup_mods: ModMask,
pub compat_lookup_mods: ModMask,
pub ptr_btn_state: KeyButMask,
}Fields
reply_type: u8device_id: u8sequence: u16length: u32mods: ModMaskbase_mods: ModMasklatched_mods: ModMasklocked_mods: ModMaskgroup: Grouplocked_group: Groupbase_group: i16latched_group: i16compat_state: ModMaskgrab_mods: ModMaskcompat_grab_mods: ModMasklookup_mods: ModMaskcompat_lookup_mods: ModMaskptr_btn_state: KeyButMaskTrait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more