Struct breadx::auto::xkb::ListComponentsReply [−][src]
pub struct ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> {
pub reply_type: u8,
pub device_id: u8,
pub sequence: u16,
pub length: u32,
pub extra: u16,
pub keymaps: Cow<'oc, [Listing<'nc>]>,
pub keycodes: Cow<'qc, [Listing<'pc>]>,
pub types: Cow<'sc, [Listing<'rc>]>,
pub compat_maps: Cow<'uc, [Listing<'tc>]>,
pub symbols: Cow<'wc, [Listing<'vc>]>,
pub geometries: Cow<'yc, [Listing<'xc>]>,
}Fields
reply_type: u8device_id: u8sequence: u16length: u32extra: u16keymaps: Cow<'oc, [Listing<'nc>]>keycodes: Cow<'qc, [Listing<'pc>]>types: Cow<'sc, [Listing<'rc>]>compat_maps: Cow<'uc, [Listing<'tc>]>symbols: Cow<'wc, [Listing<'vc>]>geometries: Cow<'yc, [Listing<'xc>]>Trait Implementations
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> AsByteSequence for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> AsByteSequence for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Clone for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Clone for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]fn clone(
&self
) -> ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
fn clone(
&self
) -> ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]Returns a copy of the value. Read more
Performs copy-assignment from source. Read more
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Debug for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Debug for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Default for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Default for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]fn default(
) -> ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
fn default(
) -> ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]Returns the “default value” for a type. Read more
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> PartialEq<ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>> for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> PartialEq<ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>> for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]fn eq(
&self,
other: &ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>
) -> bool[src]
fn eq(
&self,
other: &ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>
) -> bool[src]This method tests for self and other values to be equal, and is used
by ==. Read more
fn ne(
&self,
other: &ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>
) -> bool[src]
fn ne(
&self,
other: &ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>
) -> bool[src]This method tests for !=.
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> PartialOrd<ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>> for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> PartialOrd<ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>> for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]fn partial_cmp(
&self,
other: &ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>
) -> Option<Ordering>[src]
fn partial_cmp(
&self,
other: &ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>
) -> Option<Ordering>[src]This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> StructuralPartialEq for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>[src]Auto Trait Implementations
impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> RefUnwindSafe for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Send for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Sync for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> Unpin for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> where
'nc: 'oc,
'pc: 'qc,
'rc: 'sc,
'tc: 'uc,
'vc: 'wc,
'xc: 'yc, impl<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc> UnwindSafe for ListComponentsReply<'oc, 'nc, 'qc, 'pc, 'sc, 'rc, 'uc, 'tc, 'wc, 'vc, 'yc, 'xc>Blanket Implementations
Mutably borrows from an owned value. Read more