Struct breadx::auto::xkb::MapNotifyEvent [−][src]
pub struct MapNotifyEvent {Show fields
pub event_type: u8,
pub xkb_type: u8,
pub sequence: u16,
pub time: Timestamp,
pub device_id: u8,
pub ptr_btn_actions: u8,
pub changed: MapPart,
pub min_key_code: Keycode,
pub max_key_code: Keycode,
pub first_type: u8,
pub n_types: u8,
pub first_key_sym: Keycode,
pub n_key_syms: u8,
pub first_key_act: Keycode,
pub n_key_acts: u8,
pub first_key_behavior: Keycode,
pub n_key_behavior: u8,
pub first_key_explicit: Keycode,
pub n_key_explicit: u8,
pub first_mod_map_key: Keycode,
pub n_mod_map_keys: u8,
pub first_v_mod_map_key: Keycode,
pub n_v_mod_map_keys: u8,
pub virtual_mods: VMod,
}Fields
event_type: u8xkb_type: u8sequence: u16time: Timestampdevice_id: u8ptr_btn_actions: u8changed: MapPartmin_key_code: Keycodemax_key_code: Keycodefirst_type: u8n_types: u8first_key_sym: Keycoden_key_syms: u8first_key_act: Keycoden_key_acts: u8first_key_behavior: Keycoden_key_behavior: u8first_key_explicit: Keycoden_key_explicit: u8first_mod_map_key: Keycoden_mod_map_keys: u8first_v_mod_map_key: Keycoden_v_mod_map_keys: u8virtual_mods: VModTrait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more