Struct breadx::auto::xkb::SaMovePtr [−][src]
pub struct SaMovePtr {
pub ty: SaType,
pub flags: SaMovePtrFlag,
pub x_high: i8,
pub x_low: u8,
pub y_high: i8,
pub y_low: u8,
}Fields
ty: SaTypeflags: SaMovePtrFlagx_high: i8x_low: u8y_high: i8y_low: u8Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more