Struct breadx::auto::xkb::SetCompatMapRequest [−][src]
pub struct SetCompatMapRequest<'rb, 'sb> {
pub req_type: u8,
pub length: u16,
pub device_spec: DeviceSpec,
pub recompute_actions: bool,
pub truncate_si: bool,
pub groups: SetOfGroup,
pub first_si: u16,
pub si: Cow<'rb, [SymInterpret]>,
pub group_maps: Cow<'sb, [ModDef]>,
}Fields
req_type: u8length: u16device_spec: DeviceSpecrecompute_actions: booltruncate_si: boolgroups: SetOfGroupfirst_si: u16si: Cow<'rb, [SymInterpret]>group_maps: Cow<'sb, [ModDef]>Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more