Struct breadx::auto::xkb::SetControlsRequest [−][src]
pub struct SetControlsRequest {Show fields
pub req_type: u8,
pub length: u16,
pub device_spec: DeviceSpec,
pub affect_internal_real_mods: ModMask,
pub internal_real_mods: ModMask,
pub affect_ignore_lock_real_mods: ModMask,
pub ignore_lock_real_mods: ModMask,
pub affect_internal_virtual_mods: VMod,
pub internal_virtual_mods: VMod,
pub affect_ignore_lock_virtual_mods: VMod,
pub ignore_lock_virtual_mods: VMod,
pub mouse_keys_dflt_btn: u8,
pub groups_wrap: u8,
pub access_x_options: AxOption,
pub affect_enabled_controls: BoolCtrl,
pub enabled_controls: BoolCtrl,
pub change_controls: Control,
pub repeat_delay: u16,
pub repeat_interval: u16,
pub slow_keys_delay: u16,
pub debounce_delay: u16,
pub mouse_keys_delay: u16,
pub mouse_keys_interval: u16,
pub mouse_keys_time_to_max: u16,
pub mouse_keys_max_speed: u16,
pub mouse_keys_curve: i16,
pub access_x_timeout: u16,
pub access_x_timeout_mask: BoolCtrl,
pub access_x_timeout_values: BoolCtrl,
pub access_x_timeout_options_mask: AxOption,
pub access_x_timeout_options_values: AxOption,
pub per_key_repeat: [u8; 32],
}Fields
req_type: u8length: u16device_spec: DeviceSpecaffect_internal_real_mods: ModMaskinternal_real_mods: ModMaskaffect_ignore_lock_real_mods: ModMaskignore_lock_real_mods: ModMaskaffect_internal_virtual_mods: VModinternal_virtual_mods: VModaffect_ignore_lock_virtual_mods: VModignore_lock_virtual_mods: VModmouse_keys_dflt_btn: u8groups_wrap: u8access_x_options: AxOptionaffect_enabled_controls: BoolCtrlenabled_controls: BoolCtrlchange_controls: Controlrepeat_delay: u16repeat_interval: u16slow_keys_delay: u16debounce_delay: u16mouse_keys_delay: u16mouse_keys_interval: u16mouse_keys_time_to_max: u16mouse_keys_max_speed: u16mouse_keys_curve: i16access_x_timeout: u16access_x_timeout_mask: BoolCtrlaccess_x_timeout_values: BoolCtrlaccess_x_timeout_options_mask: AxOptionaccess_x_timeout_options_values: AxOptionper_key_repeat: [u8; 32]Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more