Struct breadx::auto::xkb::SetMapRequest [−][src]
pub struct SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> {Show fields
pub req_type: u8,
pub length: u16,
pub device_spec: DeviceSpec,
pub present: MapPart,
pub flags: SetMapFlags,
pub min_key_code: Keycode,
pub max_key_code: Keycode,
pub first_type: u8,
pub first_key_sym: Keycode,
pub total_syms: u16,
pub first_key_action: Keycode,
pub first_key_behavior: Keycode,
pub n_key_behaviors: u8,
pub first_key_explicit: Keycode,
pub n_key_explicit: u8,
pub first_mod_map_key: Keycode,
pub n_mod_map_keys: u8,
pub first_v_mod_map_key: Keycode,
pub n_v_mod_map_keys: u8,
pub virtual_mods: VMod,
pub types: Cow<'fb, [SetKeyType<'db, 'eb>]>,
pub syms: Cow<'hb, [KeySymMap<'gb>]>,
pub actions_count: Cow<'ib, [u8]>,
pub actions: Cow<'jb, [Action]>,
pub behaviors: Cow<'kb, [SetBehavior]>,
pub vmods: Cow<'lb, [u8]>,
pub explicit: Cow<'mb, [SetExplicit]>,
pub modmap: Cow<'nb, [KeyModMap]>,
pub vmodmap: Cow<'ob, [KeyVModMap]>,
}Fields
req_type: u8length: u16device_spec: DeviceSpecpresent: MapPartflags: SetMapFlagsmin_key_code: Keycodemax_key_code: Keycodefirst_type: u8first_key_sym: Keycodetotal_syms: u16first_key_action: Keycodefirst_key_behavior: Keycoden_key_behaviors: u8first_key_explicit: Keycoden_key_explicit: u8first_mod_map_key: Keycoden_mod_map_keys: u8first_v_mod_map_key: Keycoden_v_mod_map_keys: u8virtual_mods: VModtypes: Cow<'fb, [SetKeyType<'db, 'eb>]>syms: Cow<'hb, [KeySymMap<'gb>]>actions_count: Cow<'ib, [u8]>actions: Cow<'jb, [Action]>behaviors: Cow<'kb, [SetBehavior]>vmods: Cow<'lb, [u8]>explicit: Cow<'mb, [SetExplicit]>modmap: Cow<'nb, [KeyModMap]>vmodmap: Cow<'ob, [KeyVModMap]>Trait Implementations
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> AsByteSequence for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> AsByteSequence for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Clone for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Clone for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Debug for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Debug for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Default for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Default for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>Returns the “default value” for a type. Read more
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> PartialEq<SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>> for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> PartialEq<SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>> for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>fn eq(
&self,
other: &SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
) -> bool
fn eq(
&self,
other: &SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
) -> boolThis method tests for self and other values to be equal, and is used
by ==. Read more
fn ne(
&self,
other: &SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
) -> bool
fn ne(
&self,
other: &SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
) -> boolThis method tests for !=.
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> PartialOrd<SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>> for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> PartialOrd<SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>> for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>fn partial_cmp(
&self,
other: &SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
) -> Option<Ordering>
fn partial_cmp(
&self,
other: &SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Request for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Request for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> StructuralPartialEq for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>Auto Trait Implementations
impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> RefUnwindSafe for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Send for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Sync for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> Unpin for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> where
'db: 'fb,
'eb: 'fb,
'gb: 'hb, impl<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob> UnwindSafe for SetMapRequest<'fb, 'db, 'eb, 'hb, 'gb, 'ib, 'jb, 'kb, 'lb, 'mb, 'nb, 'ob>Blanket Implementations
Mutably borrows from an owned value. Read more