Struct breadx::auto::xproto::AllocColorReply [−][src]
pub struct AllocColorReply {
pub reply_type: u8,
pub sequence: u16,
pub length: u32,
pub red: u16,
pub green: u16,
pub blue: u16,
pub pixel: u32,
}Fields
reply_type: u8sequence: u16length: u32red: u16green: u16blue: u16pixel: u32Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more