Struct breadx::auto::xproto::ChangeWindowAttributesRequest [−][src]
pub struct ChangeWindowAttributesRequest {Show fields
pub req_type: u8,
pub length: u16,
pub window: Window,
pub value_mask: Cw,
pub background_pixmap: Pixmap,
pub background_pixel: u32,
pub border_pixmap: Pixmap,
pub border_pixel: u32,
pub bit_gravity: Gravity,
pub win_gravity: Gravity,
pub backing_store: BackingStore,
pub backing_planes: u32,
pub backing_pixel: u32,
pub override_redirect: Bool32,
pub save_under: Bool32,
pub event_mask: EventMask,
pub do_not_propogate_mask: EventMask,
pub colormap: Colormap,
pub cursor: Cursor,
}Fields
req_type: u8length: u16window: Windowvalue_mask: Cwbackground_pixmap: Pixmapbackground_pixel: u32border_pixmap: Pixmapborder_pixel: u32bit_gravity: Gravitywin_gravity: Gravitybacking_store: BackingStorebacking_planes: u32backing_pixel: u32override_redirect: Bool32save_under: Bool32event_mask: EventMaskdo_not_propogate_mask: EventMaskcolormap: Colormapcursor: CursorTrait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more