Struct breadx::auto::xproto::Colormap [−][src]
#[repr(transparent)]pub struct Colormap { pub xid: XID, }
Fields
xid: XIDImplementations
pub fn alloc_color<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy,
r: u16,
g: u16,
b: u16
) -> Result<RequestCookie<AllocColorRequest>>[src]
pub fn alloc_color<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy,
r: u16,
g: u16,
b: u16
) -> Result<RequestCookie<AllocColorRequest>>[src]Allocate a new color in the colormap.
pub async fn alloc_color_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
r: u16,
g: u16,
b: u16
) -> SendRequestFuture<'_, Dpy, AllocColorRequest>[src]
pub async fn alloc_color_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
r: u16,
g: u16,
b: u16
) -> SendRequestFuture<'_, Dpy, AllocColorRequest>[src]Allocate a new color in the colormap, async redox.
pub fn alloc_color_immediate<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy,
r: u16,
g: u16,
b: u16
) -> Result<ColorAllocation>[src]
pub fn alloc_color_immediate<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy,
r: u16,
g: u16,
b: u16
) -> Result<ColorAllocation>[src]Immediately allocate a new color in the colormap.
pub async fn alloc_color_immediate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
r: u16,
g: u16,
b: u16
) -> MapFuture<ExchangeRequestFuture<'_, Dpy, AllocColorRequest>, Box<dyn FnOnce(AllocColorReply) -> ColorAllocation + Send>>[src]
pub async fn alloc_color_immediate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
r: u16,
g: u16,
b: u16
) -> MapFuture<ExchangeRequestFuture<'_, Dpy, AllocColorRequest>, Box<dyn FnOnce(AllocColorReply) -> ColorAllocation + Send>>[src]Immediately allocate a new color in the colormap, async redox.