Struct breadx::auto::xproto::Window [−][src]
#[repr(transparent)]pub struct Window { pub xid: XID, }
Fields
xid: XIDImplementations
Map this window to the screen, async redox.
Unmap this window, async redox.
pub fn get_property<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy,
property: Atom,
ty: PropertyType,
delete: bool
) -> Result<RequestCookie<GetPropertyRequest>>[src]
pub fn get_property<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy,
property: Atom,
ty: PropertyType,
delete: bool
) -> Result<RequestCookie<GetPropertyRequest>>[src]Get a property of this window.
pub fn get_property_immediate<Dpy: Display + ?Sized, T: AsByteSequence>(
self,
dpy: &mut Dpy,
property: Atom,
ty: PropertyType,
delete: bool
) -> Result<Option<T>>[src]
pub fn get_property_immediate<Dpy: Display + ?Sized, T: AsByteSequence>(
self,
dpy: &mut Dpy,
property: Atom,
ty: PropertyType,
delete: bool
) -> Result<Option<T>>[src]Get a property of this window, resolving immediately.
pub fn change_property<Dpy: Display + ?Sized, T: AsByteSequence>(
self,
dpy: &mut Dpy,
property: Atom,
property_type: PropertyType,
format: PropertyFormat,
mode: PropMode,
data: &[T]
) -> Result<()>[src]
pub fn change_property<Dpy: Display + ?Sized, T: AsByteSequence>(
self,
dpy: &mut Dpy,
property: Atom,
property_type: PropertyType,
format: PropertyFormat,
mode: PropMode,
data: &[T]
) -> Result<()>[src]Change a property of the window, given an atom that identifies that property.
pub async fn change_property_async<Dpy: AsyncDisplay + ?Sized, T: AsByteSequence>(
self,
dpy: &mut Dpy,
property: Atom,
property_type: PropertyType,
format: PropertyFormat,
mode: PropMode,
data: &[T]
) -> Result<()>[src]
pub async fn change_property_async<Dpy: AsyncDisplay + ?Sized, T: AsByteSequence>(
self,
dpy: &mut Dpy,
property: Atom,
property_type: PropertyType,
format: PropertyFormat,
mode: PropMode,
data: &[T]
) -> Result<()>[src]Change a property of the window, async redox.
Delete a property of this window.
pub async fn delete_property_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
property: Atom
) -> Result[src]
pub async fn delete_property_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
property: Atom
) -> Result[src]Delete a property of this window, async redox.
Set the protocols for the WM in regards to this window.
pub async fn set_wm_protocols_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
protocols: &[Atom]
) -> Result<()>[src]
pub async fn set_wm_protocols_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
protocols: &[Atom]
) -> Result<()>[src]Set the WM protocols for this window, async redox.
Set the title for this window.
pub async fn set_title_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
title: &str
) -> Result<()>[src]
pub async fn set_title_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
title: &str
) -> Result<()>[src]Set the title for this window, async redox.
pub fn window_attributes<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<GetWindowAttributesRequest>>[src]
pub fn window_attributes<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<GetWindowAttributesRequest>>[src]Get the current set of window attributes for this window.
pub async fn window_attributes_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<GetWindowAttributesRequest>>[src]
pub async fn window_attributes_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<GetWindowAttributesRequest>>[src]Get the current set of window attributes for this window, async redox.
pub fn window_attributes_immediate<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<WindowAttributes>[src]
pub fn window_attributes_immediate<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<WindowAttributes>[src]Immediately get the current set of window attributes for this window.
pub async fn window_attributes_immediate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<WindowAttributes>[src]
pub async fn window_attributes_immediate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<WindowAttributes>[src]Immediately get the current set of window attributes for this window, async redox.
pub fn geometry<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<GetGeometryRequest>>[src]
pub fn geometry<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<GetGeometryRequest>>[src]Get the geometry of this window.
pub async fn geometry_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<GetGeometryRequest>>[src]
pub async fn geometry_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<GetGeometryRequest>>[src]Get the geometry of this window, async redox.
pub fn geometry_immediate<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<DrawableGeometry>[src]
pub fn geometry_immediate<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<DrawableGeometry>[src]Immediately get the geometry of this window.
pub async fn geometry_immediate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<DrawableGeometry>[src]
pub async fn geometry_immediate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<DrawableGeometry>[src]Immediately get the geometry of this window, async redox.
pub fn change_attributes<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy,
props: WindowParameters
) -> Result[src]
pub fn change_attributes<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy,
props: WindowParameters
) -> Result[src]Change the properties of this window.
pub async fn change_attributes_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
props: WindowParameters
) -> Result[src]
pub async fn change_attributes_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
props: WindowParameters
) -> Result[src]Change the properties of this window, async redox.
Set this window’s background color.
pub async fn set_background_color_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
clr: u32
) -> Result<()>[src]
pub async fn set_background_color_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
clr: u32
) -> Result<()>[src]Set this window’s background color, async redox.
Configure the window’s physical properties.
pub async fn configure_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
props: ConfigureWindowParameters
) -> Result[src]
pub async fn configure_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
props: ConfigureWindowParameters
) -> Result[src]Configure the window’s physical properties, async redox.
Set the border of this window.
pub async fn set_border_width_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
width: u32
) -> Result[src]
pub async fn set_border_width_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
width: u32
) -> Result[src]Set the border of this window, async redox.
Change the colormap associated with this window.
pub async fn set_colormap_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
colormap: Colormap
) -> Result[src]
pub async fn set_colormap_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
colormap: Colormap
) -> Result[src]Change the colormap associated with this window.
Change the save set for this window.
pub async fn change_save_set_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
mode: SetMode
) -> Result[src]
pub async fn change_save_set_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
mode: SetMode
) -> Result[src]Change the save set for this window, async redox.
Resize the window.
pub async fn resize_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
width: u32,
height: u32
) -> Result[src]
pub async fn resize_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
width: u32,
height: u32
) -> Result[src]Resize the window, async redox.
Move and resize the window.
pub async fn move_resize_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
x: i32,
y: i32,
width: u32,
height: u32
) -> Result[src]
pub async fn move_resize_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
x: i32,
y: i32,
width: u32,
height: u32
) -> Result[src]Move and resize the window, async redox.
Circulate this window.
pub async fn circulate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
direction: Circulate
) -> Result[src]
pub async fn circulate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
direction: Circulate
) -> Result[src]Circulate this window, async redox.
Clear an area of the window.
Clear an area of the window, async redox.
Clear the entire window, async redox.
Convert a selection in this window.
pub async fn convert_selection_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
selection: Atom,
target: Atom,
property: Atom,
time: Timestamp
) -> Result[src]
pub async fn convert_selection_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
selection: Atom,
target: Atom,
property: Atom,
time: Timestamp
) -> Result[src]Convert a selection in this window, async redox.
Set the cursor used by this window.
pub async fn set_cursor_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
cursor: Cursor
) -> Result[src]
pub async fn set_cursor_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
cursor: Cursor
) -> Result[src]Set the cursor used by this window, async redox.
Destroy this window’s subwindows.
pub async fn destroy_subwindows_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result[src]
pub async fn destroy_subwindows_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result[src]Destroy this window’s subwindows, async redox.
Free this window, async redox.
Set the event mask.
pub async fn set_event_mask_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
em: EventMask
) -> Result[src]
pub async fn set_event_mask_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
em: EventMask
) -> Result[src]Set the event mask, async redox.
Change this window’s parent and set its position within the parent.
pub async fn reparent_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
parent: Window,
x: i16,
y: i16
) -> Result[src]
pub async fn reparent_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
parent: Window,
x: i16,
y: i16
) -> Result[src]Change this window’s parent and set its position within the parent, async redox.
Map this window’s subwindows.
Map this window’s subwindows, async redox.
Unmap this window’s subwindows.
pub async fn unmap_subwindows_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result[src]
pub async fn unmap_subwindows_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result[src]Unmap this window’s subwindows, async redox.
pub fn query_tree<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<QueryTreeRequest>>[src]
pub fn query_tree<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<QueryTreeRequest>>[src]Query information regarding this window’s family tree.
pub fn query_tree_immediate<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<TreeInformation>[src]
pub fn query_tree_immediate<Dpy: Display + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<TreeInformation>[src]Query information regarding this window’s family tree and resolve immediately.
pub async fn query_tree_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<QueryTreeRequest>>[src]
pub async fn query_tree_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<RequestCookie<QueryTreeRequest>>[src]Query information regarding this window’s family tree, async redox.
pub async fn query_tree_immediate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<TreeInformation>[src]
pub async fn query_tree_immediate_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy
) -> Result<TreeInformation>[src]Query information regarding this window’s family tree and resolve immediately, async redox.
pub fn get_property_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
property: Atom,
ty: PropertyType,
delete: bool
) -> SendRequestFuture<'_, Dpy, GetPropertyRequest>ⓘNotable traits for SendRequestFuture<'a, D, R>
impl<'a, D: AsyncDisplay + ?Sized, R: Request + Unpin> Future for SendRequestFuture<'a, D, R> type Output = Result<RequestCookie<R>>;[src]
pub fn get_property_async<Dpy: AsyncDisplay + ?Sized>(
self,
dpy: &mut Dpy,
property: Atom,
ty: PropertyType,
delete: bool
) -> SendRequestFuture<'_, Dpy, GetPropertyRequest>ⓘNotable traits for SendRequestFuture<'a, D, R>
impl<'a, D: AsyncDisplay + ?Sized, R: Request + Unpin> Future for SendRequestFuture<'a, D, R> type Output = Result<RequestCookie<R>>;[src]Get a property of this window, async redox
pub async fn get_property_immediate_async<Dpy: AsyncDisplay + ?Sized, T: AsByteSequence>(
self,
dpy: &mut Dpy,
property: Atom,
ty: PropertyType,
delete: bool
) -> Result<Option<T>>[src]
pub async fn get_property_immediate_async<Dpy: AsyncDisplay + ?Sized, T: AsByteSequence>(
self,
dpy: &mut Dpy,
property: Atom,
ty: PropertyType,
delete: bool
) -> Result<Option<T>>[src]Get a property of this window, resolving immediately, async redox.