Struct breadx::auto::xv::ImageFormatInfo [−][src]
pub struct ImageFormatInfo {Show fields
pub id: u32,
pub ty: ImageFormatInfoType,
pub byte_order: ImageOrder,
pub guid: [u8; 16],
pub bpp: u8,
pub num_planes: u8,
pub depth: u8,
pub red_mask: u32,
pub green_mask: u32,
pub blue_mask: u32,
pub format: ImageFormatInfoFormat,
pub y_sample_bits: u32,
pub u_sample_bits: u32,
pub v_sample_bits: u32,
pub vhorz_y_period: u32,
pub vhorz_u_period: u32,
pub vhorz_v_period: u32,
pub vvert_y_period: u32,
pub vvert_u_period: u32,
pub vvert_v_period: u32,
pub vcomp_order: [u8; 32],
pub vscanline_order: ScanlineOrder,
}Fields
id: u32ty: ImageFormatInfoTypebyte_order: ImageOrderguid: [u8; 16]bpp: u8num_planes: u8depth: u8red_mask: u32green_mask: u32blue_mask: u32format: ImageFormatInfoFormaty_sample_bits: u32u_sample_bits: u32v_sample_bits: u32vhorz_y_period: u32vhorz_u_period: u32vhorz_v_period: u32vvert_y_period: u32vvert_u_period: u32vvert_v_period: u32vcomp_order: [u8; 32]vscanline_order: ScanlineOrderTrait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more