Struct breadx::auto::xvmc::SurfaceInfo [−][src]
pub struct SurfaceInfo {
pub id: Surface,
pub chroma_format: u16,
pub pad0: u16,
pub max_width: u16,
pub max_height: u16,
pub subpicture_max_width: u16,
pub subpicture_max_height: u16,
pub mc_type: u32,
pub flags: u32,
}Fields
id: Surfacechroma_format: u16pad0: u16max_width: u16max_height: u16subpicture_max_width: u16subpicture_max_height: u16mc_type: u32flags: u32Trait Implementations
Convert a sequence of bytes into this item.
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items. Read more
If this item has any file descriptors stored within, this function returns them.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more