[−][src]Module breadx::client_message_data
This module provides the ClientMessageData structure, which is the data type returned by the
ClientMessageEvent object.
Structs
| ClientMessageData | The data returned from a client message. This is dictated by protocol to be five 32-bit integers in length;
however, it could also represent 10 16-bit integers or 20 8-bit integers. It is usually represented as a
union; however, the |
Constants
| BYTE_INTERVAL | |
| BYTE_LEN | |
| LONG_LEN | |
| SHORT_INTERVAL | |
| SHORT_LEN |