SendmsgConnection

Struct SendmsgConnection 

pub struct SendmsgConnection { /* private fields */ }
A variant of the UnixStream connection that uses sendmsg to send data and recvmsg to receive it.

The main difference between this type and StdConnection<UnixStream> is that this type supports file descriptor passing. This is useful for extensions that require file descriptor passing.

Implementations

Source

impl SendmsgConnection

pub fn new(stream: UnixStream) -> Self

Create a new connection from a UnixStream.

pub fn into_stream(self) -> UnixStream

Convert this object back into a UnixStream.