AsyncStatus

Enum AsyncStatus 

pub enum AsyncStatus<T> {
    Ready(T),
    Read,
    Write,
    UserControlled,
}
The status of an async function.

An async function can either be ready, or be unready for a number of reasons. This enum is used to represent the status of an async function.

It can be thought of as similar to Poll, but instead of returning Pending, it returns the exact reason why it is pending.

Variants



Ready(T)

The function’s result is ready.



Read

We are waiting for a read to be available.



Write

We are waiting for a write to be available.



UserControlled

We are waiting for something else.

The implementation is expected to wake the provided waker once the function is ready to be called again.

Implementations

Source

impl<T> AsyncStatus<T>

pub fn is_ready(&self) -> bool

Returns true if the AsyncStatus is Ready.

pub fn map<R>(self, f: impl FnOnce(T) -> R) -> AsyncStatus<R>

Maps the AsyncStatus from one type to another, if the AsyncStatus is Ready.

pub fn unwrap(self) -> T

Unwrap the AsyncStatus, returning the inner value or panicking otherwise.

Panics

Panics if the AsyncStatus is not Ready.

pub fn ready(self) -> Option<T>

Convert the AsyncStatus into an Option.

Source

impl<T: Copy> AsyncStatus<&T>

pub fn copied(self) -> AsyncStatus<T>

Copy the reference in an AsyncStatus to a value.