Trait breadx::display::AsyncConnection[][src]

pub trait AsyncConnection {
    fn poll_send_packet(
        &mut self,
        bytes: &[u8],
        fds: &mut Vec<Fd>,
        cx: &mut Context<'_>,
        bytes_written: &mut usize
    ) -> Poll<Result>;
fn poll_read_packet(
        &mut self,
        bytes: &mut [u8],
        fds: &mut Vec<Fd>,
        cx: &mut Context<'_>,
        bytes_read: &mut usize
    ) -> Poll<Result>; fn establish_async(
        &mut self,
        auth_info: Option<AuthInfo>
    ) -> EstablishConnectionFuture<'_, Self> { ... } }
Asynchronous breadx connection.

Required methods

Send a packet across the connection in an async manner.

Read a packet from the connection in an async manner.

Provided methods

Establish a connection to the server.

Implementations on Foreign Types

Implementors