[−][src]Module breadx::drawable
This module contains functions that can be applied to nearly all drawable objects, such as Windows and Pixmaps.
Structs
| Geometry | The return type of |
Functions
| copy_area | Copy pixels from one area of the drawable to another. |
| copy_area_async | Copy pixels from one area of the drawable to another, async redox. |
| copy_plane | Copy a plane from one drawable to another. |
| copy_plane_async | Copy a plane from one drawable to another, async redox. |
| create_pixmap | Create a new pixmap. |
| create_pixmap_async | Create a new pixmap, async redox. |
| create_pixmap_from_image | Create a pixmap from an image. |
| create_pixmap_from_image_async | Create a pixmap from an image, async redox. |
| get_geometry | Get the geometry of a drawable object. |
| get_geometry_async | Get the geometry of a drawable object, async redox. |
| get_geometry_immediate | Immediately resolve the geometry of a drawable object. |
| get_geometry_immediate_async | Immediately resolve the geometry of a drawable object, async redox. |
| put_image | Write an image to a drawable. |
| put_image_async | Write an image to a drawable, async redox. |