[−][src]Struct breadx::image::Image
An image. This acts as a wrapper around data that represents an image.
Fields
width: usizeThe width of this image.
height: usizeThe height of this image.
x_offset: usizeNumber of pixels offset in the X direction.
format: ImageFormatFormat for this image.
depth: u8The depth of this image.
bit_order: ImageOrderBit order of this image.
byte_order: ImageOrderByte order of this image.
bitmap_unit: u8The quantity of the scanline (usually 8, 16, or 32)
bitmap_pad: u32bytes_per_line: usizebits_per_pixel: u8red_mask: u32Red mask.
green_mask: u32Green mask.
blue_mask: u32Blue mask.
data: DataThe data contained within this image.
Implementations
impl<Data> Image<Data> where
Data: Deref<Target = [u8]>, [src]
Data: Deref<Target = [u8]>,
pub fn pixel(&self, x: usize, y: usize) -> u32[src]
Get the pixel at the specified index.
pub fn new<Conn>(
dpy: &Display<Conn>,
visual: Option<&Visualtype>,
depth: u8,
format: ImageFormat,
x_offset: usize,
data: Data,
width: usize,
height: usize,
quantum: u32,
bytes_per_line: Option<usize>
) -> Option<Self>[src]
dpy: &Display<Conn>,
visual: Option<&Visualtype>,
depth: u8,
format: ImageFormat,
x_offset: usize,
data: Data,
width: usize,
height: usize,
quantum: u32,
bytes_per_line: Option<usize>
) -> Option<Self>
Create a new image, given its associated connection, visual type, depth, format, offset (should be zero unless the data starts partway into the collection), width, height, scanline quantum (8, 16, or 32) and the number of bytes per line (how many bytes between a pixel on one line and a pixel with the same X position on another line?)
pub fn data(&self) -> &[u8]ⓘ[src]
Get a reference to the interior data.
pub fn clone_to_boxed_slice(&self) -> Image<Box<[u8]>>[src]
Clone this image to an equivalent but with a boxed slice as its data.
impl<Data> Image<Data> where
Data: Deref<Target = [u8]> + DerefMut, [src]
Data: Deref<Target = [u8]> + DerefMut,
pub fn set_pixel(&mut self, x: usize, y: usize, pixel: u32)[src]
Set a pixel at the specified coordinates to the specified value.