pub struct Arc {
pub x: i16,
pub y: i16,
pub width: u16,
pub height: u16,
pub angle1: i16,
pub angle2: i16,
}Fields
x: i16y: i16width: u16height: u16angle1: i16angle2: i16Trait Implementations
sourceimpl Ord for Arc
impl Ord for Arc
sourceimpl PartialOrd<Arc> for Arc
impl PartialOrd<Arc> for Arc
sourcefn partial_cmp(&self, other: &Arc) -> Option<Ordering>
fn partial_cmp(&self, other: &Arc) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for Arc
impl Eq for Arc
impl StructuralEq for Arc
impl StructuralPartialEq for Arc