pub struct ExposeEvent {
pub response_type: u8,
pub sequence: u16,
pub window: u32,
pub x: u16,
pub y: u16,
pub width: u16,
pub height: u16,
pub count: u16,
}Expand description
NOT YET DOCUMENTED.
Fields
window- The exposed (damaged) window.x- The X coordinate of the left-upper corner of the exposed rectangle, relative to thewindow’s origin.y- The Y coordinate of the left-upper corner of the exposed rectangle, relative to thewindow’s origin.width- The width of the exposed rectangle.height- The height of the exposed rectangle.count- The amount ofExposeevents following this one. Simple applications that do not want to optimize redisplay by distinguishing between subareas of its window can just ignore all Expose events with nonzero counts and perform full redisplays on events with zero counts.
Fields
response_type: u8sequence: u16window: u32x: u16y: u16width: u16height: u16count: u16Trait Implementations
sourceimpl Clone for ExposeEvent
impl Clone for ExposeEvent
sourcefn clone(&self) -> ExposeEvent
fn clone(&self) -> ExposeEvent
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ExposeEvent
impl Debug for ExposeEvent
sourceimpl Default for ExposeEvent
impl Default for ExposeEvent
sourcefn default() -> ExposeEvent
fn default() -> ExposeEvent
Returns the “default value” for a type. Read more
sourceimpl Hash for ExposeEvent
impl Hash for ExposeEvent
sourceimpl Ord for ExposeEvent
impl Ord for ExposeEvent
sourceimpl PartialEq<ExposeEvent> for ExposeEvent
impl PartialEq<ExposeEvent> for ExposeEvent
sourcefn eq(&self, other: &ExposeEvent) -> bool
fn eq(&self, other: &ExposeEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ExposeEvent) -> bool
fn ne(&self, other: &ExposeEvent) -> bool
This method tests for !=.
sourceimpl PartialOrd<ExposeEvent> for ExposeEvent
impl PartialOrd<ExposeEvent> for ExposeEvent
sourcefn partial_cmp(&self, other: &ExposeEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &ExposeEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl TryParse for ExposeEvent
impl TryParse for ExposeEvent
sourcefn try_parse(initial_value: &[u8]) -> Result<(ExposeEvent, &[u8]), ParseError>
fn try_parse(initial_value: &[u8]) -> Result<(ExposeEvent, &[u8]), ParseError>
Try to parse the given values into an instance of this type. Read more
impl Copy for ExposeEvent
impl Eq for ExposeEvent
impl StructuralEq for ExposeEvent
impl StructuralPartialEq for ExposeEvent