Fields
red: u16green: u16blue: u16Trait Implementations
sourceimpl Ord for Rgb
impl Ord for Rgb
sourceimpl PartialOrd<Rgb> for Rgb
impl PartialOrd<Rgb> for Rgb
sourcefn partial_cmp(&self, other: &Rgb) -> Option<Ordering>
fn partial_cmp(&self, other: &Rgb) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for Rgb
impl Eq for Rgb
impl StructuralEq for Rgb
impl StructuralPartialEq for Rgb