pub struct UngrabKeyboardRequest {
pub time: u32,
}Fields
time: u32Implementations
sourceimpl UngrabKeyboardRequest
impl UngrabKeyboardRequest
sourcepub fn serialize(
self
) -> (Vec<Cow<'static, [u8]>, Global>, Vec<RawFdContainer, Global>)
pub fn serialize(
self
) -> (Vec<Cow<'static, [u8]>, Global>, Vec<RawFdContainer, Global>)
Serialize this request into bytes for the provided connection
sourcepub fn try_parse_request(
header: RequestHeader,
value: &[u8]
) -> Result<UngrabKeyboardRequest, ParseError>
pub fn try_parse_request(
header: RequestHeader,
value: &[u8]
) -> Result<UngrabKeyboardRequest, ParseError>
Parse this request given its header, its body, and any fds that go along with it