Struct breadx::AuthInfo [−][src]
pub struct AuthInfo {
pub name: String,
pub data: Vec<u8>,
pub family: u16,
pub address: Vec<u8>,
pub number: Vec<u8>,
}Expand description
Information needed to authorize a user to use an X11 connection.
Fields
name: Stringdata: Vec<u8>family: u16address: Vec<u8>number: Vec<u8>Implementations
Reads in the auth info from the given reading stream.
Reads in the auth info from the given reading stream, async redox.
Reads in the auth info from the file specified by the XAUTHORITY environment variable.
Reads in the auth info from the file specified by the XAuthority variable, async redox.