pub struct Error { /* private fields */ }Expand description
An error that may occur during operation of this crate.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn make_msg<D: Display>(msg: D) -> Self
pub fn make_msg<D: Display>(msg: D) -> Self
Create a new error from something that can be formatted into a message.
Sourcepub fn unsupported(&self) -> bool
pub fn unsupported(&self) -> bool
Did this error happen as the result of calling an unsupported operation?
Sourcepub fn make_parse_error(pe: ParseError) -> Self
pub fn make_parse_error(pe: ParseError) -> Self
Create an error from an X11 parse error.
Sourcepub fn make_missing_extension(name: &'static str) -> Self
pub fn make_missing_extension(name: &'static str) -> Self
Create an error from a missing extension.
Sourcepub fn invalid_state(&self) -> bool
pub fn invalid_state(&self) -> bool
Did this error happen as a result of some state-based object entering an invalid state?
Sourcepub fn initialization(&self) -> bool
pub fn initialization(&self) -> bool
Did this error occur during initialization of the X11 connection?
Sourcepub fn as_setup_failure(&self) -> Option<&SetupFailure>
pub fn as_setup_failure(&self) -> Option<&SetupFailure>
Get the inner setup failure that this error is a wrapper around.
Sourcepub fn into_setup_failure(self) -> Result<SetupFailure>
pub fn into_setup_failure(self) -> Result<SetupFailure>
Convert this error into a setup failure.