Trait breadx::Request[][src]

pub trait Request: AsByteSequence {
    type Reply: AsByteSequence;

    const OPCODE: u8;
    const EXTENSION: Option<&'static str>;
    const REPLY_EXPECTS_FDS: bool;
}
A request that can be sent as an instruction to the X server.

Associated Types

Associated Constants

The name of the extension that this request belongs to.

Whether or not this request’s reply includes file descriptors.

Implementors