[−][src]Module breadx::tutorials
This module contains tutorials on how to use breadx and the X Window System Protocol.
Modules
| basics | In the last tutorial, we reached an elementary understanding of how the X protocol works. In this tutorial, we'll open a connection to the X server and create a window. |
| color | Last time, we discussed events and how to react to them. Today, we'll talk about color management. It may seem like a trivial subject, but it carries a surprising amount of importance within X11. |
| drawing |
|
| event | Last time, we implemented a basic window. Today, we'll add event handling to that window, and use that to add some functionality. |
| intro | In this series of tutorials, I will teach you how to use |