[−][src]Trait breadx::auto::AsByteSequence
Internal use helper trait. This represents an item that can be converted to and from a series of bytes.
Required methods
pub fn size(&self) -> usize[src]
Get the size needed to store this item in terms of bytes. Higher is better than lower here, since this is mostly used to allocate buffers for items.
pub fn as_bytes(&self, bytes: &mut [u8]) -> usize[src]
Append this item to a sequence of bytes.
pub fn from_bytes(bytes: &[u8]) -> Option<(Self, usize)>[src]
Convert a sequence of bytes into this item.