[−][src]Struct breadx::client_message_data::ClientMessageData
The data returned from a client message. This is dictated by protocol to be five 32-bit integers in length;
however, it could also represent 10 16-bit integers or 20 8-bit integers. It is usually represented as a
union; however, the bytes, shorts, and longs methods can be used to access each of these
representations.
Implementations
impl ClientMessageData[src]
#[must_use]pub fn bytes(&self) -> &[u8]ⓘ[src]
Get the bytes assocated with this sequence.
#[must_use]pub fn shorts(&self) -> &[u16]ⓘ[src]
Get the short integers assocated with this sequence.
#[must_use]pub fn longs(&self) -> &[u32]ⓘ[src]
Get the long integers associated with this sequence.
#[must_use]pub fn bytes_mut(&mut self) -> &mut [u8]ⓘ[src]
Get a mutable reference to the bytes associated with this sequence.
#[must_use]pub fn shorts_mut(&mut self) -> &mut [u16]ⓘ[src]
Get a mutable reference to the short integers associated with this sequence.
#[must_use]pub fn longs_mut(&mut self) -> &mut [u32]ⓘ[src]
Get a mutable reference to the long integers associated with this sequence.