[][src]Module breadx::display

This module defines the Display object, which acts as a connection to the X11 server, and the Connection trait, which the Display object abstracts itself over. See the documentation for these objects for more information.

Re-exports

pub use crate::auto::xproto::Atom;
pub use crate::auto::xproto::BackingStore;
pub use crate::auto::xproto::ChangePropertyRequest;
pub use crate::auto::xproto::ChangeSaveSetRequest;
pub use crate::auto::xproto::ChangeWindowAttributesRequest;
pub use crate::auto::xproto::Circulate;
pub use crate::auto::xproto::CirculateWindowRequest;
pub use crate::auto::xproto::ClearAreaRequest;
pub use crate::auto::xproto::Colormap;
pub use crate::auto::xproto::ConfigWindow;
pub use crate::auto::xproto::ConfigureWindowRequest;
pub use crate::auto::xproto::ConvertSelectionRequest;
pub use crate::auto::xproto::Cursor;
pub use crate::auto::xproto::DeletePropertyRequest;
pub use crate::auto::xproto::DestroySubwindowsRequest;
pub use crate::auto::xproto::DestroyWindowRequest;
pub use crate::auto::xproto::EventMask;
pub use crate::auto::xproto::Gcontext;
pub use crate::auto::xproto::GetGeometryRequest;
pub use crate::auto::xproto::GetWindowAttributesReply;
pub use crate::auto::xproto::GetWindowAttributesRequest;
pub use crate::auto::xproto::Gravity;
pub use crate::auto::xproto::MapState;
pub use crate::auto::xproto::MapWindowRequest;
pub use crate::auto::xproto::PropMode;
pub use crate::auto::xproto::SetMode;
pub use crate::auto::xproto::StackMode;
pub use crate::auto::xproto::Timestamp;
pub use crate::auto::xproto::Visualid;
pub use crate::auto::xproto::Window;
pub use crate::auto::xproto::WindowClass;
pub use crate::auto::xproto::ATOM_WM_NAME;
pub use crate::auto::AsByteSequence;
pub use crate::display::Display;
pub use crate::display::RequestCookie;
pub use crate::send_request;
pub use crate::sr_request;

Modules

name

This module defines the NameConnection type, which is the default connection used for Display objects. See the NameConnection object for more information.

Structs

Configs
ConfigureWindowParameters
Display

The connection to the X11 server. Most operations done in breadx revolve around this object in some way, shape or form.

GcParameters
Geometry

The return type of drawable::get_geometry_immediate.

KbParameters
Modifiers
RequestCookie

A cookie for a request.

WindowAttributes

The return type of Window::window_attributes_immediate.

WindowGeometry

The return type of Window::geometry_immediate.

WindowParameters

Enums

ColorAllocation

The result of a color allocation call.

PropertyFormat

The format of the property being changed.

PropertyType

The type of the property being changed.

Traits

AsyncConnection

Asynchronous breadx connection.

Connection

Synchronous breadx connection.

DisplayLike

Represents an object that contains a Display and can successfully be aliased to a display.

XidType

A type that acts as a wrapper around an XID.

Functions

rgb

Convenience function for producing an RGB pixel value for supported monitors.

Type Definitions

AsyncDisplayConnection
ContextID

Unique identifier for a context.

DisplayConnection

A variant of Display that uses X11's default connection mechanisms to connect to the server. In most cases, you should be using this over any variant of Display.

GenericConnFuture

Generic future for connections;