[−][src]Module breadx::display
This module defines the Display object, which acts as a connection to the X11 server, and the
Connection trait, which the Display object abstracts itself over. See the documentation for
these objects for more information.
Modules
| name | This module defines the |
Structs
| Configs | |
| Display | The connection to the X11 server. Most operations done in breadx revolve around this object in some way, shape or form. |
| GcParameters | |
| KbParameters | |
| RequestCookie | A cookie for a request. |
| WindowParameters |
Traits
| Connection | A trait that represents the ability to send and receive bytes across a connection. This is used as a two-way stream to send and receive data from the X server. |
Type Definitions
| ContextID | Unique identifier for a context. |
| DisplayConnection | A variant of |
| GenericFuture | A boxed future, for returning from a trait. |