pub enum AsyncStatus<T> {
Ready(T),
Read,
Write,
UserControlled,
}Expand description
The status of an async function.
An async function can either be ready, or be unready for a number of reasons. This enum is used to represent the status of an async function.
It can be thought of as similar to Poll, but instead of returning
Pending, it returns the exact reason why it is pending.
Variants
Ready(T)
The function’s result is ready.
Read
We are waiting for a read to be available.
Write
We are waiting for a write to be available.
UserControlled
We are waiting for something else.
The implementation is expected to wake the provided waker once the function is ready to be called again.
Implementations
Sourceimpl<T> AsyncStatus<T>
impl<T> AsyncStatus<T>
Sourceimpl<T: Copy> AsyncStatus<&T>
impl<T: Copy> AsyncStatus<&T>
Sourcepub fn copied(self) -> AsyncStatus<T>
pub fn copied(self) -> AsyncStatus<T>
Copy the reference in an AsyncStatus to a value.