Module breadx::display::name [−][src]
This module defines the NameConnection type, which is the default connection used for Display objects.
See the NameConnection object for more information.
Enums
An async version of the NameConnection object. See NameConnection’s documentation for more information.
This is a wrapper around the connection created by DisplayConnection::create(). It implements
Connection for a variety of connections that X11 usually transmits itself over, and should be the
connection most users of breadx end up using.