Struct breadx::display::BasicDisplay [−][src]
pub struct BasicDisplay<Conn> { /* fields omitted */ }Expand description
An implementor of Display and AsyncDisplay that requires &mut access in order to use.
This is the standard implementation of a display for the X11 protocol. In addition to storing the connection to the server and the setup information received from the server, it contains the event queues, pending item map, and provides XIDs and sequence numbers.
It is recommended to create an instance of this object via DisplayConnection::create(), since that
function uses the system’s variables in order to connect to the X11 server. However, niche use cases who need
to communicate with the X server in other ways should use [BasicDisplay::from_connection].
Connection Poisoning
If a panic occurs while sending/receiving along the connection, or if a future involving sending/receiving
across the connection is dropped, the connection may be “poisoned”. Attempting to use the connection after
it is poisoned will result in a panic, since the current state of the BasicDisplay is invalid and will
result in invalid communications with the X11 server. The exact semantics of what, exactly, will cause a
connection poisoning are not well defined at the moment. However, the connection should never be poisoned
during normal operation of the BasicDisplay.
Mutability
BasicDisplay requires an &mut reference for most operations, including sending and receiving requests and
replies. Although this “inherited mutability”, as we call it, may be convenient for architectures of programs
where multiple objects require access to the X server, it allows the connection to prevent undefined
behavior from occurring. To quote the rust std documentation for
std::cell:
The more common inherited mutability, where one must have unique access to mutate a value, is one of the key language elements that enables Rust to reason strongly about pointer aliasing, statically preventing crash bugs. Because of that, inherited mutability is preferred, and interior mutability is something of a last resort.
That being said, the CellDisplay object is preferred over using RefCell<BasicDisplay>, since it uses
several different cell types in order to reduce reentrant panics. However, using SyncDisplay instead of
Mutex<BasicDisplay> may not be preferred depending on your use case. See the documentation for
SyncDisplay for more information.
Implementations
Establishes this display using an inner connection type. This receives setup information from the server on the other side of the connection in order to populate the display.
In order to produce the Setup, from_connection sends a SetupRequest object across the provided
connection. This SetupRequest is populated with the AuthInfo provided by either the user, or the
file specified by the XAUTHORITY environment variable if the auth_info parameter is None. Once the
Setup has been received, it is stored in the BasicDisplay and the BasicDisplay is considered valid.
Finally, default_screen is used to dictate the default screen this display uses.
In addition, this function also tries to establish bigreq support, and if it does it enables the
corresponding variables in the `BasicDisplay.
Errors
If the server returns error code 0, this function will return BreadError::FailedToConnect, indicating
that the server refused our connection. If the server returns error code 2, this function will return
BreadError::FailedToAuthorize, indicating that the AuthInfo provided either by the user or the
“XAUTHORITY” is invalid. This function may also return an IO error if a system error occurs while
communicating with the server.
In addition, this function may also return BreadError::BadObjectRead if the Setup provided by the
server is invalid, but this will likely never occur unless a malicious X11 server is used.
Example
use breadx::display::BasicDisplay; use std::net::TcpStream; let server = TcpStream::connect("127.0.0.1:60000")?; let conn = BasicDisplay::from_connection(server, 0, None)?;
Establishes this display using an inner connection type. This receives setup information from the server on the other side of the connection in order to populate the display. This method uses async types in order to ensure that the operation is non-blocking.
See BasicDisplay::from_connection for more information.
Example
use async_io::Async; use blocking::unblock; use breadx::display::BasicDisplay; use std::net::TcpStream; let server = blocking::unblock(|| TcpStream::connect("127.0.0.1:60000")).await?; let server = Async::new(server)?; let conn = BasicDisplay::from_connection_async(server, 0, None).await?;
Create a new connection to the X server, given an optional name and authorization information.
This function instantiates a new NameConnection using either the name specification string passed
by the user, or the environment variable “DISPLAY” if the name parameter is None. The
NameConnection is either a TCP stream connected to port 60000 + X on the host, where X is the
display number, or a Unix socket connection to one of the X11 system sockets.
Once the NameConnection is created, it is passed into BasicDisplay::from_connection method to
establish the BasicDisplay.
This is the recommended way to create a BasicDisplay object, since most system running an X11 server
expect the user to use the “DISPLAY” variable in order to connect to it. from_connection should only
be used for niche use cases.
Errors
In addition to the errors that from_connection can return, this method may return
BreadError::UnableToParseConnection if the name string is improperly formatted, or an IO error if a
system error occurs while trying to connect to the server.
Example
Connect to the default X11 server, as specified by the environment variables.
use breadx::DisplayConnection; let conn = DisplayConnection::create(None, None)?;
Connect to the server on display 3, using the authorization info read from a file.
use breadx::{AuthInfo, DisplayConnection}; use std::fs::File; let mut file = File::open("my_auth_info.txt")?; let mut auth_info = AuthInfo::from_stream(&mut file).expect("AuthInfo not found"); let conn = DisplayConnection::create(Some(":3".into()), Some(auth_info.remove(0)))?;