[−][src]Trait breadx::display::Connection
A trait that represents the ability to send and receive bytes across a connection. This is used as a two-way stream to send and receive data from the X server.
Required methods
pub fn send_packet(&mut self, bytes: &[u8]) -> Result[src]
Send bytes in a packet across the connection in a blocking manner.
pub fn read_packet(&mut self, bytes: &mut [u8]) -> Result[src]
Read a packet/request from the connection in a blocking manner.