pub type DisplayConnection = BasicDisplay<BufConnection<NameConnection>>;
A Display that has connected to an X11 server using the usual transports.
Display
This is a good default Display to use in most cases.
Connect to the server using the given display name.