[−][src]Trait breadx::Request
A request that can be sent as an instruction to the X server.
Associated Types
type Reply: AsByteSequence[src]
Associated Constants
pub const OPCODE: u8[src]
pub const EXTENSION: Option<&'static str>[src]
The name of the extension that this request belongs to.
pub const REPLY_EXPECTS_FDS: bool[src]
Whether or not this request's reply includes file descriptors.